package preface

  1. Overview
  2. Docs
On This Page
  1. Infix operators
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Bounded_join_semilattice.API

The complete interface of a Bounded_join_semillatice.

type t

The type hold by the Bounded_join_semilattice

Functions

include WITH_BOTTOM with type t := t
val bottom : t

The bottom value represent the least element of the join semilattice

include Join_semilattice.WITH_JOIN with type t := t
val join : t -> t -> t

join x y is the least upper bound of {x,y}.

Infix operators

module Infix : INFIX with type t := t
val (||) : t -> t -> t

Infix version of join.